# mountaineer-exceptions

A small plugin for mountaineer that shows beautiful tracebacks in the browser.

This repository also acts as our proof-of-concept for Mountaineer [Plugins](https://github.com/piercefreeman/mountaineer/issues/201).
